@@ -101,13 +101,40 @@ class SubmissionPropertiesHandler(ExtensionBaseHandler):
                 endpoint=f"{self.service_base_url}/lectures/{lecture_id}/assignments/{assignment_id}/submissions/{submission_id}/properties",
                 header=self.grader_authentication_header,
                 body=self.request.body.decode("utf-8"),
-                decode_response=False
+                decode_response=False,
+                request_timeout=300.0
             )
         except HTTPClientError as e:
             self.log.error(e.response)
             raise HTTPError(e.code, reason=e.response.reason)
         self.write("OK")
 
+@register_handler(
+    path=r"\/lectures\/(?P<lecture_id>\d*)\/assignments\/(?P<assignment_id>\d*)\/submissions\/(?P<submission_id>\d*)\/edit\/?"
+)
+class SubmissionEditHandler(ExtensionBaseHandler):
+    async def put(self, lecture_id: int, assignment_id: int, submission_id: int):
+        """ Sends a PUT-request to the grader service to create or overide a edit repository of the submission
+
+        :param lecture_id: id of the lecture
+        :type lecture_id: int
+        :param assignment_id: id of the assignment
+        :type assignment_id: int
+        :param submission_id: id of the submission
+        :type submission_id: int
+        """
+        try:
+            response = await self.request_service.request(
+                method="PUT",
+                endpoint=f"{self.service_base_url}/lectures/{lecture_id}/assignments/{assignment_id}/submissions/{submission_id}/edit",
+                header=self.grader_authentication_header,
+                body=self.request.body.decode("utf-8")
+            )
+        except HTTPClientError as e:
+            self.log.error(e.response)
+            raise HTTPError(e.code, reason=e.response.reason)
+        self.write(json.dumps(response))
+
 
 @register_handler(
     path=r"\/lectures\/(?P<lecture_id>\d*)\/assignments\/(?P<assignment_id>\d*)\/submissions\/(?P<submission_id>\d*)\/?"
