@@ -15,15 +15,17 @@ import {
 import DashboardIcon from '@mui/icons-material/Dashboard';
 import FormatListNumberedIcon from '@mui/icons-material/FormatListNumbered';
 import QueryStatsIcon from '@mui/icons-material/QueryStats';
-import {Assignment} from '../../model/assignment';
-import {Lecture} from '../../model/lecture';
-import {getAllSubmissions} from '../../services/submissions.service';
-import {GradingComponent} from './grading-view/grading';
-import {OverviewComponent} from './overview-view/overview';
-import {Submission} from '../../model/submission';
-import {StatsComponent} from "./stats-view/stats";
-import {GradeBook} from "../../services/gradebook";
-import {loadNumber, storeNumber} from "../../services/storage.service";
+import SettingsIcon from '@mui/icons-material/Settings';
+import { Assignment } from '../../model/assignment';
+import { Lecture } from '../../model/lecture';
+import { getAllSubmissions } from '../../services/submissions.service';
+import { GradingComponent } from './grading/grading';
+import { OverviewComponent } from './overview/overview';
+import { Submission } from '../../model/submission';
+import { StatsComponent } from './stats/stats';
+import { GradeBook } from '../../services/gradebook';
+import { loadNumber, storeNumber } from '../../services/storage.service';
+import { SettingsComponent } from './settings/settings';
 
 export interface IAssignmentModalProps {
   lecture: Lecture;
@@ -40,7 +42,7 @@ export const AssignmentModalComponent = (props: IAssignmentModalProps) => {
     props.latestSubmissions
   );
   const [navigation, setNavigation] = React.useState(
-    loadNumber("cm-navigation", null, props.assignment) || 0
+    loadNumber('cm-navigation', null, props.assignment) || 0
   );
 
   return (
@@ -84,18 +86,24 @@ export const AssignmentModalComponent = (props: IAssignmentModalProps) => {
             root={props.root}
           />
         )}
+        {navigation === 3 && (
+          <SettingsComponent
+            assignment={props.assignment}
+            lecture={props.lecture}
+            submissions={props.latestSubmissions}
+          />
+        )}
       </Box>
 
       <Paper
-        sx={{position: 'absolute', bottom: 0, left: 0, right: 0}}
+        sx={{ position: 'absolute', bottom: 0, left: 0, right: 0 }}
         elevation={3}
       >
         <BottomNavigation
           showLabels
           value={navigation}
           onChange={(event, newValue) => {
-            console.log(newValue);
-            storeNumber("cm-navigation", newValue, null, props.assignment);
+            storeNumber('cm-navigation', newValue, null, props.assignment);
             setNavigation(newValue);
             getAllSubmissions(
               props.lecture,
@@ -107,7 +115,7 @@ export const AssignmentModalComponent = (props: IAssignmentModalProps) => {
             });
           }}
         >
-          <BottomNavigationAction label="Overview" icon={<DashboardIcon/>}/>
+          <BottomNavigationAction label="Overview" icon={<DashboardIcon />} />
           <BottomNavigationAction
             label="Submissions"
             icon={
@@ -116,11 +124,12 @@ export const AssignmentModalComponent = (props: IAssignmentModalProps) => {
                 badgeContent={props.latestSubmissions?.length}
                 showZero={props.latestSubmissions !== null}
               >
-                <FormatListNumberedIcon/>
+                <FormatListNumberedIcon />
               </Badge>
             }
           />
-          <BottomNavigationAction label="Stats" icon={<QueryStatsIcon/>}/>
+          <BottomNavigationAction label="Stats" icon={<QueryStatsIcon />} />
+          <BottomNavigationAction label="Settings" icon={<SettingsIcon />} />
         </BottomNavigation>
       </Paper>
     </Box>
