@@ -8,9 +8,9 @@ import * as React from 'react';
 import { useFormik } from 'formik';
 import * as yup from 'yup';
 
-import AdapterDateFns from '@mui/lab/AdapterDateFns';
-import LocalizationProvider from '@mui/lab/LocalizationProvider';
-import DateTimePicker from '@mui/lab/DateTimePicker';
+import { LocalizationProvider } from '@mui/x-date-pickers/LocalizationProvider';
+import { AdapterDateFns } from '@mui/x-date-pickers/AdapterDateFns';
+import { DateTimePicker } from '@mui/x-date-pickers/DateTimePicker';
 import {
   Button,
   TextField,
@@ -34,12 +34,10 @@ import {
   Typography
 } from '@mui/material';
 import { Assignment } from '../../model/assignment';
-import { Submission } from '../../model/submission';
 import { LoadingButton } from '@mui/lab';
 import EditIcon from '@mui/icons-material/Edit';
 import {
-  createAssignment,
-  deleteAssignment
+  createAssignment
 } from '../../services/assignments.service';
 import { Lecture } from '../../model/lecture';
 import TypeEnum = Assignment.TypeEnum;
@@ -74,281 +72,6 @@ const validationSchema = yup.object({
     .min(1, 'Students must be able to at least submit once')
 });
 
-export interface IEditDialogProps {
-  lecture: Lecture;
-  assignment: Assignment;
-  submissions: any[];
-  onSubmit?: (updatedAssignment: Assignment) => void;
-  onClose: () => void;
-}
-
-export const EditDialog = (props: IEditDialogProps) => {
-  const [checked, setChecked] = React.useState(
-    props.assignment.due_date !== null
-  );
-  const [checkedLimit, setCheckedLimit] = React.useState(
-    Boolean(props.assignment.max_submissions)
-  );
-  const formik = useFormik({
-    initialValues: {
-      name: props.assignment.name,
-      due_date:
-        props.assignment.due_date !== null
-          ? new Date(props.assignment.due_date)
-          : null,
-      type: props.assignment.type,
-      automatic_grading: props.assignment.automatic_grading,
-      max_submissions: (props.assignment.max_submissions || null),
-      allow_files: (props.assignment.allow_files || false)
-    },
-    validationSchema: validationSchema,
-    onSubmit: values => {
-      if (values.max_submissions !== null) {
-        values.max_submissions = +values.max_submissions;
-      }
-      const updatedAssignment: Assignment = Object.assign(
-        props.assignment,
-        values
-      );
-      if (props.onSubmit) {
-        props.onSubmit(updatedAssignment);
-      }
-      setOpen(false);
-    }
-  });
-
-  const [openDialog, setOpen] = React.useState(false);
-  return (
-    <div>
-      <Tooltip title={'Edit Assignment'}>
-        <IconButton
-          sx={{ mt: -1 }}
-          onClick={e => {
-            e.stopPropagation();
-            setOpen(true);
-          }}
-          onMouseDown={event => event.stopPropagation()}
-          aria-label="edit"
-        >
-          <EditIcon />
-        </IconButton>
-      </Tooltip>
-      <Dialog open={openDialog} onBackdropClick={() => setOpen(false)}>
-        <DialogTitle>Edit Assignment</DialogTitle>
-        <form onSubmit={formik.handleSubmit}>
-          <DialogContent>
-            <Stack spacing={2} sx={{ ml: 2, mr: 2 }}>
-              <TextField
-                variant="outlined"
-                fullWidth
-                id="name"
-                name="name"
-                label="Assignment Name"
-                value={formik.values.name}
-                onChange={formik.handleChange}
-                error={formik.touched.name && Boolean(formik.errors.name)}
-                helperText={formik.touched.name && formik.errors.name}
-              />
-
-              <LocalizationProvider dateAdapter={AdapterDateFns}>
-                <FormControlLabel
-                  control={
-                    <Checkbox
-                      checked={checked}
-                      onChange={async e => {
-                        setChecked(e.target.checked);
-                        if (!e.target.checked) {
-                          await formik.setFieldValue('due_date', null);
-                        } else {
-                          await formik.setFieldValue('due_date', new Date());
-                        }
-                      }}
-                    />
-                  }
-                  label="Set Deadline"
-                />
-                <DateTimePicker
-                  ampm={false}
-                  disabled={!checked}
-                  renderInput={(props: TextFieldProps) => {
-                    return (
-                      <TextField
-                        {...props}
-                        helperText={
-                          formik.touched.due_date && formik.errors.due_date
-                        }
-                        error={
-                          formik.touched.due_date &&
-                          Boolean(formik.errors.due_date)
-                        }
-                      />
-                    );
-                  }}
-                  label="DateTimePicker"
-                  value={formik.values.due_date}
-                  onChange={date => {
-                    formik.setFieldValue('due_date', date);
-                  }}
-                />
-              </LocalizationProvider>
-
-              <FormControlLabel
-                control={
-                  <Checkbox
-                    checked={checkedLimit}
-                    onChange={async e => {
-                      setCheckedLimit(e.target.checked);
-                      if (!e.target.checked) {
-                        await formik.setFieldValue('max_submissions', null);
-                      } else {
-                        await formik.setFieldValue('max_submissions', 1);
-                      }
-                    }}
-                  />
-                }
-                label="Limit Number of Submissions"
-              />
-
-              <TextField
-                variant="outlined"
-                fullWidth
-                disabled={!checkedLimit}
-                type={'number'}
-                id="max-submissions"
-                name="max_submissions"
-                placeholder="Submissions"
-                value={formik.values.max_submissions || null}
-                InputProps={{ inputProps: { min: 1 } }}
-                onChange={e => {
-                  formik.setFieldValue('max_submissions', +e.target.value);
-                }}
-                helperText={
-                  formik.touched.max_submissions &&
-                  formik.errors.max_submissions
-                }
-                error={
-                  Boolean(formik.values.max_submissions) &&
-                  formik.values.max_submissions < 1
-                }
-              />
-
-              <InputLabel id="demo-simple-select-label-auto">
-                Auto-Grading Behaviour
-                <Tooltip title={gradingBehaviourHelp}>
-                  <HelpOutlineOutlinedIcon
-                    fontSize={'small'}
-                    sx={{ ml: 1.5, mt: 1.0 }}
-                  />
-                </Tooltip>
-              </InputLabel>
-              <TextField
-                select
-                id="assignment-type-select"
-                value={formik.values.automatic_grading}
-                label="Auto-Grading Behaviour"
-                placeholder="Grading"
-                onChange={e => {
-                  formik.setFieldValue('automatic_grading', e.target.value);
-                }}
-              >
-                <MenuItem value={'auto'}>Automatic Grading</MenuItem>
-                <MenuItem value={'full_auto'}>Fully Automatic Grading</MenuItem>
-                <MenuItem value={'unassisted'}>No Automatic Grading</MenuItem>
-              </TextField>
-
-              <FormControlLabel
-                control={
-                  <Checkbox
-                    checked={formik.values.allow_files}
-                    onChange={async e => {
-                      console.log(e.target.checked);
-                      await formik.setFieldValue('allow_files', e.target.checked);
-                    }}
-                  />
-                }
-                label="Allow file upload by students"
-              />
-
-              {/* Not included in release 1.0
-              <InputLabel id="demo-simple-select-label">Type</InputLabel>
-              <Select
-                labelId="assignment-type-select-label"
-                id="assignment-type-select"
-                value={formik.values.type}
-                label="Type"
-                disabled={
-                  props.assignment.status === 'complete' ||
-                  props.assignment.status === 'released'
-                }
-                onChange={e => {
-                  formik.setFieldValue('type', e.target.value);
-                }}
-              >
-                <MenuItem value={'user'}>User</MenuItem>
-                <MenuItem value={'group'}>Group</MenuItem>
-              </Select>*/}
-
-              <Button
-                fullWidth
-                color="error"
-                variant="contained"
-                disabled={
-                  props.assignment.status === 'released' ||
-                  props.assignment.status === 'complete' ||
-
-                  props.submissions.length > 0
-                }
-                onClick={async () => {
-                  await deleteAssignment(
-                    props.lecture.id,
-                    props.assignment.id
-                  ).then(
-                    response => {
-                      setOpen(false);
-                      props.onClose();
-                    },
-                    (error: Error) => {
-                      enqueueSnackbar(error.message, {
-                        variant: 'error'
-                      });
-                    }
-                  );
-                }}
-              >
-                Delete Assignment
-              </Button>
-              <small
-                hidden={
-                  props.assignment.status !== 'released' &&
-                  props.assignment.status !== 'complete'
-                }
-              >
-                Can not delete assignment while it is released/completed or has
-                submissions!
-              </small>
-            </Stack>
-          </DialogContent>
-          <DialogActions>
-            <Button
-              color="primary"
-              variant="outlined"
-              onClick={() => {
-                setOpen(false);
-              }}
-            >
-              Cancel
-            </Button>
-
-            <Button color="primary" variant="contained" type="submit">
-              Submit
-            </Button>
-          </DialogActions>
-        </form>
-      </Dialog>
-    </div>
-  );
-};
-
 const validationSchemaLecture = yup.object({
   name: yup
     .string()
@@ -488,7 +211,8 @@ export const CreateDialog = (props: ICreateDialogProps) => {
       allow_files: false
     },
     validationSchema: validationSchema,
-    onSubmit: values => {if (values.max_submissions !== null) {
+    onSubmit: values => {
+      if (values.max_submissions !== null) {
         values.max_submissions = +values.max_submissions;
       }
       const newAssignment: Assignment = {
@@ -567,19 +291,19 @@ export const CreateDialog = (props: ICreateDialogProps) => {
                     return (
                       <TextField
                         {...props}
-                        helperText={
-                          formik.touched.due_date && formik.errors.due_date
-                        }
                         error={
                           formik.touched.due_date &&
                           Boolean(formik.errors.due_date)
                         }
+                        helperText={
+                          formik.touched.due_date &&
+                          String(formik.errors.due_date)}
                       />
                     );
                   }}
                   label="DateTimePicker"
                   value={formik.values.due_date}
-                  onChange={date => {
+                  onChange={(date: Date) => {
                     formik.setFieldValue('due_date', date);
                   }}
                 />
@@ -649,7 +373,10 @@ export const CreateDialog = (props: ICreateDialogProps) => {
                     checked={formik.values.allow_files}
                     onChange={async e => {
                       console.log(e.target.checked);
-                      await formik.setFieldValue('allow_files', e.target.checked);
+                      await formik.setFieldValue(
+                        'allow_files',
+                        e.target.checked
+                      );
                     }}
                   />
                 }
@@ -792,7 +519,7 @@ export const AgreeDialog = (props: IAgreeDialogProps) => {
           onClick={() => executeAction(props.handleAgree)}
           autoFocus
         >
-          Agree
+          <span>Agree</span>
         </LoadingButton>
       </DialogActions>
     </Dialog>
@@ -827,7 +554,6 @@ export const ReleaseDialog = (props: IReleaseDialogProps) => {
       />
       <Dialog
         open={commitOpen}
-        onBackdropClick={() => setCommitOpen(false)}
         onClose={() => setCommitOpen(false)}
         fullWidth={true}
         maxWidth={'sm'}
@@ -869,7 +595,7 @@ export const ReleaseDialog = (props: IReleaseDialogProps) => {
               setCommitOpen(false);
             }}
           >
-            Commit and Release
+            <span>Commit and Release</span>
           </LoadingButton>
         </DialogActions>
       </Dialog>
